@@ -9,53 +9,54 @@
 
 """
 
-from datalad.support.path import (
-    basename,
-    join as opj,
-    normpath,
-    relpath,
-)
-
 from datalad.api import (
+    Dataset,
     clone,
     create,
-    Dataset,
     install,
     siblings,
 )
-from datalad.support.gitrepo import GitRepo
 from datalad.support.exceptions import InsufficientArgumentsError
-
-from datalad.tests.utils import (
-    chpwd,
-    create_tree,
-    with_tempfile, with_testrepos,
+from datalad.support.gitrepo import GitRepo
+from datalad.support.path import basename
+from datalad.support.path import join as opj
+from datalad.support.path import (
+    normpath,
+    relpath,
+)
+from datalad.tests.utils_pytest import (
+    DEFAULT_BRANCH,
+    DEFAULT_REMOTE,
     assert_false,
     assert_in,
     assert_in_results,
     assert_not_in,
     assert_raises,
-    assert_status,
     assert_result_count,
-    with_sameas_remote,
+    assert_status,
+    chpwd,
+    create_tree,
     eq_,
     ok_,
     serve_path_via_http,
-    DEFAULT_BRANCH,
-    DEFAULT_REMOTE,
+    with_sameas_remote,
+    with_tempfile,
+    with_testrepos,
 )
-
 from datalad.utils import (
-    on_windows,
     Path,
+    on_windows,
 )
 
 
-# work on cloned repos to be safer
-@with_testrepos('submodule_annex', flavors=['clone'])
+@with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
 @with_tempfile
-def test_siblings(origin, repo_path, local_clone_path):
+def test_siblings(origin=None, repo_path=None, local_clone_path=None):
+    ca = dict(result_renderer='disabled')
+    # a remote dataset with a subdataset underneath
+    origds = Dataset(origin).create(**ca)
+    _ = origds.create('subm 1', **ca)
 
     sshurl = "ssh://push-remote.example.com"
     httpurl1 = "http://remote1.example.com/location"
@@ -65,10 +66,10 @@ def test_siblings(origin, repo_path, local_clone_path):
     # we need a dataset to work at
     with chpwd(repo_path):  # not yet there
         assert_raises(InsufficientArgumentsError,
-                      siblings, 'add', url=httpurl1)
+                      siblings, 'add', url=httpurl1, **ca)
 
     # prepare src
-    source = install(repo_path, source=origin, recursive=True)
+    source = install(repo_path, source=origin, recursive=True, **ca)
     # pollute config
     depvar = 'remote.test-remote.datalad-publish-depends'
     source.config.add(depvar, 'stupid', scope='local')
@@ -81,7 +82,7 @@ def test_siblings(origin, repo_path, local_clone_path):
         url=httpurl1,
         publish_depends=['r1', 'r2'],
         on_failure='ignore',
-        result_renderer='disabled')
+        **ca)
     assert_status('error', res)
     eq_(res[0]['message'],
         ('unknown sibling(s) specified as publication dependency: %s',
@@ -93,7 +94,7 @@ def test_siblings(origin, repo_path, local_clone_path):
                    dataset=source, name="test-remote",
                    url=httpurl1,
                    result_xfm='paths',
-                   result_renderer='disabled')
+                   **ca)
 
     eq_(res, [source.path])
     assert_in("test-remote", source.repo.get_remotes())
@@ -102,29 +103,25 @@ def test_siblings(origin, repo_path, local_clone_path):
 
     # reconfiguring doesn't change anything
     siblings('configure', dataset=source, name="test-remote",
-             url=httpurl1,
-             result_renderer='disabled')
+             url=httpurl1, **ca)
     assert_in("test-remote", source.repo.get_remotes())
     eq_(httpurl1,
         source.repo.get_remote_url("test-remote"))
     # re-adding doesn't work
     res = siblings('add', dataset=source, name="test-remote",
-                   url=httpurl1, on_failure='ignore',
-                   result_renderer='disabled')
+                   url=httpurl1, on_failure='ignore', **ca)
     assert_status('error', res)
     # only after removal
-    res = siblings('remove', dataset=source, name="test-remote",
-                   result_renderer='disabled')
+    res = siblings('remove', dataset=source, name="test-remote", **ca)
     assert_status('ok', res)
     assert_not_in("test-remote", source.repo.get_remotes())
     # remove again (with result renderer to smoke-test a renderer
     # special case for this too)
-    res = siblings('remove', dataset=source, name="test-remote")
+    res = siblings('remove', dataset=source, name="test-remote", **ca)
     assert_status('notneeded', res)
 
     res = siblings('add', dataset=source, name="test-remote",
-                   url=httpurl1, on_failure='ignore',
-                   result_renderer='disabled')
+                   url=httpurl1, on_failure='ignore', **ca)
     assert_status('ok', res)
 
     # add another remove with a publication dependency
@@ -138,7 +135,7 @@ def test_siblings(origin, repo_path, local_clone_path):
                    publish_depends='test-remote',
                    # just for smoke testing
                    publish_by_default=DEFAULT_BRANCH,
-                   result_renderer='disabled')
+                   **ca)
     assert_status('ok', res)
     # config replaced with new setup
     #source.config.reload(force=True)
@@ -148,8 +145,7 @@ def test_siblings(origin, repo_path, local_clone_path):
     # add to another remote automagically taking it from the url
     # and being in the dataset directory
     with chpwd(source.path):
-        res = siblings('add', url=httpurl2,
-                       result_renderer='disabled')
+        res = siblings('add', url=httpurl2, **ca)
     assert_result_count(
         res, 1,
         name="remote2.example.com", type='sibling')
@@ -159,7 +155,7 @@ def test_siblings(origin, repo_path, local_clone_path):
     res = siblings('configure',
                    dataset=source, name="test-remote",
                    url=httpurl1 + "/elsewhere",
-                   result_renderer='disabled')
+                   **ca)
     assert_status('ok', res)
     eq_(httpurl1 + "/elsewhere",
         source.repo.get_remote_url("test-remote"))
@@ -174,7 +170,7 @@ def test_siblings(origin, repo_path, local_clone_path):
     #    add_sibling(dataset=source, name="test-remote",
     #                url=httpurl1 + "/elsewhere")
     #assert_in("""'test-remote' already exists with conflicting settings""",
-    #          str(cm.exception))
+    #          str(cm.value))
     ## add a push url without force fails, since in a way the fetch url is the
     ## configured push url, too, in that case:
     #with assert_raises(RuntimeError) as cm:
@@ -182,14 +178,14 @@ def test_siblings(origin, repo_path, local_clone_path):
     #                url=httpurl1 + "/elsewhere",
     #                pushurl=sshurl, force=False)
     #assert_in("""'test-remote' already exists with conflicting settings""",
-    #          str(cm.exception))
+    #          str(cm.value))
 
     # add push url (force):
     res = siblings('configure',
                    dataset=source, name="test-remote",
                    url=httpurl1 + "/elsewhere",
                    pushurl=sshurl,
-                   result_renderer='disabled')
+                   **ca)
     assert_status('ok', res)
     eq_(httpurl1 + "/elsewhere",
         source.repo.get_remote_url("test-remote"))
@@ -205,7 +201,8 @@ def test_siblings(origin, repo_path, local_clone_path):
             recursive=True,
             # we need to disable annex queries, as it will try to access
             # the fake URL configured above
-            get_annex_info=False):
+            get_annex_info=False,
+            **ca):
         repo = GitRepo(r['path'], create=False)
         assert_in("test-remote", repo.get_remotes())
         url = repo.get_remote_url("test-remote")
@@ -227,7 +224,7 @@ def test_siblings(origin, repo_path, local_clone_path):
             # we need to disable annex queries, as it will try to access
             # the fake URL configured above
             get_annex_info=False,
-            result_renderer='disabled'):
+            **ca):
         repo = GitRepo(r['path'], create=False)
         assert_in("test-remote-2", repo.get_remotes())
         url = repo.get_remote_url("test-remote-2")
@@ -261,7 +258,7 @@ def test_siblings(origin, repo_path, local_clone_path):
             # we need to disable annex queries, as it will try to access
             # the fake URL configured above
             get_annex_info=False,
-            result_renderer='disabled'):
+            **ca):
         repo = GitRepo(r['path'], create=False)
         assert_in("test-remote-3", repo.get_remotes())
         url = repo.get_remote_url("test-remote-3")
@@ -278,7 +275,7 @@ def test_siblings(origin, repo_path, local_clone_path):
 
 
 @with_tempfile(mkdir=True)
-def test_here(path):
+def test_here(path=None):
     # few smoke tests regarding the 'here' sibling
     ds = create(path)
     res = ds.siblings(
@@ -328,7 +325,7 @@ def test_here(path):
 
 
 @with_tempfile(mkdir=True)
-def test_no_annex(path):
+def test_no_annex(path=None):
     # few smoke tests regarding the 'here' sibling
     ds = create(path, annex=False)
     res = ds.siblings(
@@ -351,7 +348,7 @@ def test_no_annex(path):
 
 @with_tempfile()
 @with_tempfile()
-def test_arg_missing(path, path2):
+def test_arg_missing(path=None, path2=None):
     # test fix for gh-3553
     ds = create(path)
     assert_raises(
@@ -400,11 +397,11 @@ def test_arg_missing(path, path2):
 
 @with_sameas_remote
 @with_tempfile(mkdir=True)
-def test_sibling_enable_sameas(repo, clone_path):
+def test_sibling_enable_sameas(repo=None, clone_path=None):
     ds = Dataset(repo.path)
     create_tree(ds.path, {"f0": "0"})
     ds.save(path="f0")
-    ds.repo.copy_to(["f0"], remote="r_dir")
+    ds.push(["f0"], to="r_dir")
     ds.repo.drop(["f0"])
 
     ds_cloned = clone(ds.path, clone_path)
@@ -437,7 +434,7 @@ def test_sibling_enable_sameas(repo, clone_path):
 
 
 @with_tempfile(mkdir=True)
-def test_sibling_inherit(basedir):
+def test_sibling_inherit(basedir=None):
     ds_source = Dataset(opj(basedir, "source")).create()
 
     # In superdataset, set up remote "source" that has git-annex group "grp".
@@ -457,7 +454,7 @@ def test_sibling_inherit(basedir):
 
 
 @with_tempfile(mkdir=True)
-def test_sibling_inherit_no_super_remote(basedir):
+def test_sibling_inherit_no_super_remote(basedir=None):
     ds_source = Dataset(opj(basedir, "source")).create()
     ds_super = Dataset(opj(basedir, "super")).create()
     ds_clone = ds_super.clone(
@@ -470,7 +467,7 @@ def test_sibling_inherit_no_super_remote(basedir):
 
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
-def test_sibling_path_is_posix(basedir, otherpath):
+def test_sibling_path_is_posix(basedir=None, otherpath=None):
     ds_source = Dataset(opj(basedir, "source")).create()
     # add remote with system native path
     ds_source.siblings(
@@ -489,7 +486,7 @@ def test_sibling_path_is_posix(basedir, otherpath):
 
 
 @with_tempfile()
-def test_bf3733(path):
+def test_bf3733(path=None):
     ds = create(path)
     # call siblings configure for an unknown sibling without a URL
     # doesn't work, but also doesn't crash
@@ -515,7 +512,8 @@ def test_bf3733(path):
 @serve_path_via_http
 @with_tempfile(mkdir=True)
 @serve_path_via_http
-def test_as_common_datasource(testbed, viapath, viaurl, remotepath, url, remotepath2, url2):
+def test_as_common_datasource(testbed=None, viapath=None, viaurl=None,
+                              remotepath=None, url=None, remotepath2=None, url2=None):
     ds = Dataset(remotepath).create()
     (ds.pathobj / 'testfile').write_text('likemagic')
     (ds.pathobj / 'testfile2').write_text('likemagic2')
@@ -590,7 +588,7 @@ def test_as_common_datasource(testbed, viapath, viaurl, remotepath, url, remotep
 
 @with_tempfile(mkdir=True)
 @with_tempfile(mkdir=True)
-def test_specialremote(dspath, remotepath):
+def test_specialremote(dspath=None, remotepath=None):
     ds = Dataset(dspath).create()
     ds.repo.call_annex(
         ['initremote', 'myremote', 'type=directory',
