@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -19,6 +19,7 @@ import os
 import sys
 import traceback
 
+from datalad.support.exceptions import CapturedException
 
 lgr = logging.getLogger("datalad.docutils")
 
@@ -172,8 +173,11 @@ def _parse_parameters(paramdoc):
     entries = __re_spliter1.split(paramdoc)
     result = [(__re_spliter2.split(e)[0].strip(), e)
               for e in entries if e != '']
-    lgr.debug('parseParameters: Given "%s", we split into %s' %
-              (paramdoc, result))
+    lgr.log(
+        1,
+        'parseParameters: Given "%s", we split into %s',
+        paramdoc, result,
+    )
     return result
 
 
@@ -313,62 +317,10 @@ def borrowkwargs(cls=None, methodname=None, exclude=None):
     return _borrowkwargs
 
 
-# TODO: make limit respect config/environment parameter
 def exc_str(exc=None, limit=None, include_str=True):
-    """Enhanced str for exceptions.  Should include original location
+    """Temporary adapter
 
-    Parameters
-    ----------
-    exc: Exception, optional
-      If not provided, information about the last exception caught by except
-      clause (as provided by `sys.exc_info`) will be used.
-    limit: int, optional
-      Number of levels in the traceback stack from the point where exception
-      was raised to include. If `None`, environment variable
-      DATALAD_EXC_STR_TBLIMIT is consulted.
-    include_str: bool, optional
-      Either include str (or `repr` if empty `str`) into representation.
-      If False, just ends up reporting traceback without string representation
-      of exception pre-pended.
-
-    Returns
-    -------
-    str
-      String representation of the exception with traceback information
-      appended.
+    The CapturedException should be available and be used directly instead.
     """
-    out = str(exc) if include_str else ""
-    if limit is None:
-        # TODO: config logging.exceptions.traceback_levels = 1
-        limit = int(os.environ.get('DATALAD_EXC_STR_TBLIMIT', '1'))
-    try:
-        exctype, value, tb = sys.exc_info()
-        if not exc:
-            exc = value
-            if include_str:
-                out = str(exc)
-        if include_str and not out:
-            out = repr(exc)
-        # verify that it seems to be the exception we were passed
-        #assert(isinstance(exc, exctype))
-        if exc:
-            assert(exc is value)
-        entries = traceback.extract_tb(tb)
-        if entries:
-            tb_str = "[%s]" % (
-                ','.join(
-                    '%s:%s:%d' % (os.path.basename(x[0]), x[2], x[1])
-                    for x in entries[-limit:]
-                )
-            )
-            if out:
-                out = "%s %s" % (out, tb_str)
-            else:
-                out = tb_str
-    except:  # MIH: TypeError?
-        return out  # To the best of our abilities
-    finally:
-        # As the bible teaches us:
-        # https://docs.python.org/2/library/sys.html#sys.exc_info
-        del tb
-    return out
+
+    return str(CapturedException(exc))
