@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -30,9 +30,9 @@ from ..utils import (
     unlink,
 )
 from .credentials import (
-    CREDENTIAL_TYPES,
     CompositeCredential,
 )
+from datalad.downloaders import CREDENTIAL_TYPES
 from ..support.exceptions import (
     AccessDeniedError,
     AccessPermissionExpiredError,
@@ -48,8 +48,6 @@ from ..support.locking import (
     try_lock_informatively,
 )
 
-from ..support.network import RI
-
 from logging import getLogger
 lgr = getLogger('datalad.downloaders')
 
@@ -139,6 +137,12 @@ class BaseDownloader(object, metaclass=ABCMeta):
             needs_authentication = authenticator.requires_authentication
         else:
             needs_authentication = self.credential
+
+        # TODO: not sure yet, where is/are the right spot(s) to pass the URL:
+        if hasattr(self.credential, 'set_context'):
+            lgr.debug("set credential context as %s", url)
+            self.credential.set_context(auth_url=url)
+
         attempt, incomplete_attempt = 0, 0
         result = None
         credential_was_refreshed = False
@@ -297,7 +301,6 @@ class BaseDownloader(object, metaclass=ABCMeta):
             break
         return provider
 
-
     def _enter_credentials(
             self, url, denied_msg,
             auth_types=[], new_provider=True):
@@ -343,6 +346,9 @@ class BaseDownloader(object, metaclass=ABCMeta):
                     "Failed to download from %s given available credentials"
                     % url)
 
+        lgr.debug("set credential context as %s", url)
+        self.credential.set_context(auth_url=url)
+
     @staticmethod
     def _get_temp_download_filename(filepath):
         """Given a filepath, return the one to use as temp file during download
@@ -626,7 +632,7 @@ class BaseDownloader(object, metaclass=ABCMeta):
         bytes
           content
         """
-        lgr.info("Fetching %r", url)
+        lgr.debug("Fetching %r", url)
         # Do not return headers, just content
         out = self.access(self._fetch, url, **kwargs)
         return out[0]
