@@ -85,9 +85,6 @@ class _CachedRepo(object):
             paths=[rpath],
             # a simple `exists()` will not be enough (pointer files, etc...)
             eval_availability=True,
-            # if it truly is a symlink, not just an annex pointer, we would not
-            # want to resolve it
-            eval_file_type=True,
         )
         finfo = finfo.popitem()[1] if finfo else {}
         return finfo
