@@ -8,28 +8,25 @@
 """Test saveds function"""
 
 
-from datalad.tests.utils import (
+from datalad.distribution.dataset import Dataset
+from datalad.support.annexrepo import AnnexRepo
+from datalad.support.gitrepo import GitRepo
+from datalad.tests.utils_pytest import (
     assert_in,
     assert_not_in,
-    create_tree,
-    with_tempfile,
-    eq_,
-    known_failure_windows,
-)
-
-from datalad.distribution.dataset import Dataset
-from datalad.support.gitrepo import GitRepo
-from datalad.support.annexrepo import AnnexRepo
-from datalad.tests.utils import (
     assert_repo_status,
+    create_tree,
+    eq_,
     get_annexstatus,
     get_convoluted_situation,
+    known_failure_windows,
     slow,
+    with_tempfile,
 )
 
 
 @with_tempfile
-def test_save_basics(path):
+def test_save_basics(path=None):
     ds = Dataset(path).create()
     # nothing happens
     eq_(list(ds.repo.save(paths=[], _status={})),
@@ -69,19 +66,19 @@ def _test_save_all(path, repocls):
 @slow  # 11sec on travis
 @known_failure_windows  # see gh-5462
 @with_tempfile
-def test_gitrepo_save_all(path):
+def test_gitrepo_save_all(path=None):
     _test_save_all(path, GitRepo)
 
 
 @slow  # 11sec on travis
 @known_failure_windows  # see gh-5462
 @with_tempfile
-def test_annexrepo_save_all(path):
+def test_annexrepo_save_all(path=None):
     _test_save_all(path, AnnexRepo)
 
 
 @with_tempfile
-def test_save_to_git(path):
+def test_save_to_git(path=None):
     ds = Dataset(path).create()
     create_tree(
         ds.path,
