@@ -9,15 +9,14 @@
 
 from packaging.version import Version
 
-from .utils import *
-
-
 import datalad
 from datalad.support.network import (
     get_url_response_stamp,
     is_url_quoted,
 )
 
+from .utils_pytest import *
+
 
 def test_is_url_quoted():
     ok_(is_url_quoted('%22%27%3ba&b&cd|'))
